@@ -6,7 +6,7 @@ use Carp;
 use parent 'Exporter';
 our @EXPORT = qw(binary_search);
 
-our $VERSION = '0.96_02';
+our $VERSION = '0.97';
 
 sub binary_search {
     my ($posmin, $posmax, $target, $readfn, $handle, $smallblock) = @_;
@@ -65,21 +65,25 @@ __END__
 
 =head1 NAME
 
-Search::Binary - generic binary search
+Search::Binary - generic binary search (DEPRECATED)
 
 =head1 SYNOPSIS
 
   use Search::Binary;
-  $pos = binary_search($min, $max, $val, $read, $handle, [$size]);
+  my $pos = binary_search($min, $max, $val, $read, $handle, [$size]);
 
 =head1 DESCRIPTION
 
-C<binary_search> implements a generic binary search algorithm returning the
-I<position> of the first I<record> whose I<index value> is greater than or
-equal to C<$val>. The search routine does not define any of the terms
-I<position>, I<record> or I<index value>, but leaves their interpretation
-and implementation to the user supplied function C<&$read()>. The only
-restriction is that positions must be integer scalars.
+Instead of using C<Search:Binary>, for most cases L<List::BinarySearch> offers
+same functionality with simpler, more robust API and thus the latter should be
+preferred and this module should be considered deprecated.
+
+C<binary_search> subroutine (which is exported by default) implements a generic
+binary search algorithm returning the I<position> of the first I<record> which
+I<index value> is greater than or equal to C<$val>. The search routine does not
+define any of the terms I<position>, I<record> or I<index value>, but leaves
+their interpretation and implementation to the user supplied function
+C<&$read()>. The only restriction is that positions must be integer scalars.
 
 During the search the read function will be called with three arguments:
 the input parameters C<$handle> and C<$val>, and a position.  If the position
@@ -103,9 +107,46 @@ determines when the algorithms switches to a sequential search. C<$val> is
 an index value. The value of C<$handle> is of no consequence to the binary
 search algorithm; it is merely passed as a convenience to the read function.
 
-=head1 COPYRIGHT
+=head1 USAGE
 
-  Copyright 1998, Erik Rantapaa
+For simple case of binary search in array of numbers, one can use
+C<Search::Binary> with following closure accepting array reference and
+returning reader function:
+
+  sub make_numeric_array_reader {
+      my ( $array ) = @_;
+      my $current_pos = 0;
+      return sub {
+          my ( $self, $value, $pos ) = @_;
+          $pos = $current_pos + 1 unless defined $pos;
+          $current_pos = $pos;
+          return ( $pos < scalar @{$array}
+                   ? $value <=> $array->[$pos]
+                   : -1, # see RT #52326
+                   $pos );
+      };
+  }
+  # search $value position in non-empty @array of numbers
+  binary_search 0, @array - 1, $value, make_numeric_array_reader(\@array);
+
+Using L<List::BinarySearch>, equivaluent of above code would be:
+
+  binsearch_pos { $a <=> $b } $value, @array;
+
+so unless one wants to use more generic algorithm (e.g. for some objects
+instead of arrays), L<List::BinarySearch> functions should be preferred.
+
+=head1 SEE ALSO
+
+=over 4
+
+=item * L<List::BinarySearch>
+
+=back
+
+=head1 COPYRIGHT AND LICENSE
+
+Copyright 1998, Erik Rantapaa
 
 This library is free software; you can redistribute it and/or
 modify it under the same terms as Perl itself.
